Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
arrakis/__init__.py | 15 | 3 | 0 | 80.0%
arrakis/__main__.py | 153 | 62 | 0 | 59.5%
arrakis/api.py | 15 | 1 | 0 | 93.3%
arrakis/block.py | 181 | 17 | 3 | 90.6%
arrakis/channel.py | 64 | 6 | 2 | 90.6%
arrakis/client.py | 94 | 4 | 0 | 95.7%
arrakis/constants.py | 8 | 0 | 0 | 100.0%
arrakis/flight.py | 123 | 8 | 3 | 93.5%
arrakis/mux.py | 78 | 21 | 0 | 73.1%
arrakis/publish.py | 99 | 75 | 5 | 24.2%
Total | 830 | 197 | 13 | 76.3%

No items found using the specified filter.